@@ -117,24 +117,26 @@ Axes::Axes(ocpl::Handle Parent) : Object(Parent) , numticks(6)
   COPY_DEFAULT(XAxisLocation,Radio);
   COPY_DEFAULT(YAxisLocation,Radio);
   COPY_DEFAULT(LineWidth,Scalar);
+  COPY_DEFAULT(FontSize,Scalar);
   COPY_DEFAULT(TickLength,Matrix);
   COPY_DEFAULT(XScale,Radio);
   COPY_DEFAULT(YScale,Radio);
   COPY_DEFAULT(ZScale,Radio);
   COPY_DEFAULT(GridLineStyle,Radio);
   COPY_DEFAULT(Box,Radio);
+  COPY_DEFAULT(Tag,String);
 
-//   auto_tickers = new Ticks*[2];
-//   auto_tickers[0] = new Ticks(0,Self,10.);
-//   auto_tickers[1] = new Ticks(1,Self,10.);
+  auto_tickers = new Ticks*[2];
+  auto_tickers[0] = new Ticks(0,Self,10.);
+  auto_tickers[1] = new Ticks(1,Self,10.);
 }
 
 Axes::~Axes()
 {
   _DEBUG_PRINT("In ~axes\n");
-//   delete auto_tickers[0];
-//   delete auto_tickers[1];
-//   delete [] auto_tickers;
+  delete auto_tickers[0];
+  delete auto_tickers[1];
+  delete [] auto_tickers;
 }
 
 void Axes::Parse(ocpl::command& command)
@@ -159,9 +161,15 @@ void Axes::Parse(ocpl::command& command)
         return;
       }
     }
+    else if(command.id()==ocpl::patch) {
+      if(command.nargin() != 3) {
+        ret_error(command,"patch accepts 3 arguments");
+        return;
+      }
+    }
     else {
       if(command.nargin()!=2) {
-        ret_error(command,"line/patch accepts 2 arguments");
+        ret_error(command,"line accepts 2 arguments");
         return;
       }
     }
@@ -184,7 +192,12 @@ void Axes::Parse(ocpl::command& command)
       hnd = new double(static_cast<double>(line->GetHandle()));
     }
     else if(command.id()==ocpl::patch) {
-      Patch* patch = new Patch(GetHandle(),XData,YData);
+      Matrix CData(command.argin(2)->real_data(),
+          command.argin(2)->nr,
+          command.argin(2)->nc);
+      // the data should not be deleted by command
+      command.argin(2)->owner=false;
+      Patch* patch = new Patch(GetHandle(),XData,YData,CData);
       ((HandleVect *)GetProperty("Children"))->Add(patch->GetHandle());
       hnd = new double(static_cast<double>(patch->GetHandle()));
     }
@@ -444,12 +457,13 @@ void Axes::draw()
   MAKE_REF(xcolor,ColorNone);
   MAKE_REF(ycolor,ColorNone);
   MAKE_REF(box,Radio);
+  MAKE_REF(linewidth,Scalar);
 
   GLdouble eqn[4] = {0,0,0,0};
   // Set figure local coord system
   glPushMatrix();
   glMatrixMode(GL_MODELVIEW);
-  //  glLoadIdentity();
+  // glLoadIdentity();
 
   // Setup clipping planes
   eqn[0] = 1;
@@ -491,9 +505,11 @@ void Axes::draw()
       1.0);
   glTranslated( -xlimits[0], -ylimits[0], 0);
 
+
   if(visible()=="on") {
     // Draw Axes
-    glLineWidth(((Scalar*)GetProperty("LineWidth"))->GetVal());
+    glLineWidth(linewidth());
+    if(printing) gl2psLineWidth( linewidth() );
     glBegin(GL_LINES);
     if(xcolor.IsColor()) {
       SET_COLOR(xcolor);
@@ -514,14 +530,16 @@ void Axes::draw()
       }
     }
     glEnd();
+    glLineWidth(1.0);
+    if(printing) gl2psLineWidth( 1.0);
 
     ocpl::Real dx,dy;
     GetPixel(dx,dy);
     // Draw Ticks and gridlines
     MAKE_REF(xtick,Matrix);
     MAKE_REF(ytick,Matrix);
-    NEXT_LAYER
-      DrawOneAxis(x_axis,xtick,xlimits,ylimits,dy,xscale()=="log",yscale()=="log",box()=="on");
+    NEXT_LAYER;
+    DrawOneAxis(x_axis,xtick,xlimits,ylimits,dy,xscale()=="log",yscale()=="log",box()=="on");
     DrawOneAxis(y_axis,ytick,ylimits,xlimits,dx,yscale()=="log",xscale()=="log",box()=="on");
 
     // All children
@@ -533,15 +551,16 @@ void Axes::draw()
     title.AllDraw();
   }
 
-  // draw each child in it's own layer, back to front
-  for ( children.First() ; !children.IsDone() ; children.Next() ) {
+  // draw each child in it's own layer, front to back. Legend always
+  // on top
+  for ( children.Last() ; !children.IsDoneR() ; children.Prev() ) {
     NEXT_LAYER;
-    (::GetObjectD(children.CurrentHandle()))->draw();
+    (::GetObjectD(children.CurrentHandleR()))->draw();
   }
-
   NEXT_LAYER;
   legend.AllDraw();
 
+
   glPopMatrix();
 }
 
@@ -667,89 +686,18 @@ void Axes::AutoScale()
   SetupLimits();
 }
 
-// void Axes::AutoTicksAxis(Matrix& lim, Matrix& tick, bool log, int direction, double pixelSize)
-// {
-//   assert(direction==0 || direction==1);
-
-//   auto_tickers[direction]->SetRange(lim(0),lim(1));
-
-//   auto_tickers[direction]->SetPixelSize(pixelSize);
-//   auto_tickers[direction]->SetLogScale(log);
-
-//   auto_tickers[direction]->GetAutoTicks(tick);
-// }
-
-void Axes::AutoTicksAxis(Matrix& lim,Matrix& tick,bool log)
+void Axes::AutoTicksAxis(Matrix& lim, Matrix& tick, bool log, int direction, double pixelSize)
 {
-  double dt;
-  double* t;
-  int    nt;
+  assert(direction==0 || direction==1);
 
-  if(!log) {
-    double fexp = floor(log10(fabs(lim(1)-lim(0))));
-    double sx = fabs(lim(1)-lim(0))/pow(10.0, fexp)/10.0;   /* scaled x */
-    double rx = floor(sx);                    /* rounded x */
-    double f = 10*(sx - rx);                  /* fraction between 0 and 10 */
+  auto_tickers[direction]->SetRange(lim(0),lim(1));
 
-    if(f<=1)      dt = 0.1;
-    else if(f<=2) dt = 0.2;
-    else if(f<=6) dt = 0.5;
-    else          dt = 1.0;
+  auto_tickers[direction]->SetPixelSize(pixelSize);
+  auto_tickers[direction]->SetLogScale(log);
 
-    dt *= copysign(pow(10.0,fexp), lim(1)-lim(0));
-    nt = static_cast<int>(floor((lim(1)-lim(0))/dt));
-    double t0 = ceil(lim(0)/dt)*dt;
-    if( fabs(t0 + nt*dt) <= fabs(lim(1))) nt++;
-
-    t = new double[nt];
-    t[0] = t0;
-    for(int i=1;i<nt;i++) {
-      t[i] = t[i-1] + dt;
-      if(fabs(t[i])<1e-14) t[i]=0;
-     }
-  }
-  else {
-    double llim[2];
-    llim[0] = log10(lim(0));
-    llim[1] = log10(lim(1));
-
-    double fexp = floor(log10(fabs(llim[1]-llim[0])));
-    double sx = fabs(llim[1]-llim[0])/pow(10.0, fexp)/10.0;   /* scaled x */
-    double rx = floor(sx);                    /* rounded x */
-    double f = 10*(sx - rx);                  /* fraction between 0 and 10 */
-
-         if(f< 2) dt = 0.1;
-    else if(f< 3) dt = 0.2;
-    else if(f< 7) dt=0.5;
-    else          dt = 1.0;
-
-    dt *= copysign(pow(10.0,fexp), llim[1]-llim[0]);
-    int dd = static_cast<int>(1.0/dt);
-    nt = static_cast<int>(floor((llim[1]-llim[0])*dd))+1;
-    double t0 = ceil(llim[0]);
-
-    t = new double[nt];
-    t[0] = pow(10.0,t0);
-    int i;
-    for(i=0;i<nt;i++) {
-      double tt0 = pow(10.0,t0+i/dd);
-      if(i%dd ) t[i] = (i%dd)*dt*pow(10.0,1+floor(log10(tt0)));
-      else t[i] = tt0;
-
-      // FIXME
-      // bruteforce way, instead of calculating :/
-      if(t[i]>lim(1)) break;
-    }
-    nt = i;
-    if(t[nt-1]>lim(1)) nt--;
-  }
-  Matrix* tempt = new Matrix(t,nt,1);
-  tick = *tempt;
-  delete tempt;
+  auto_tickers[direction]->GetAutoTicks(tick);
 }
 
-
-
 //! formats tick positions into a "a|b|c|d" string
 void Axes::TickLabels(Matrix& tick, String& label)
 {
@@ -824,11 +772,9 @@ void Axes::AutoTicks()
   GetPixel(dx,dy);
 
   if(xtickmode()=="auto")
-    //    AutoTicksAxis(xlim,xtick,xscale()=="log",0,dx);
-    AutoTicksAxis(xlim,xtick,xscale()=="log");
+    AutoTicksAxis(xlim,xtick,xscale()=="log",0,dx);
   if(ytickmode()=="auto")
-    //    AutoTicksAxis(ylim,ytick,yscale()=="log",1,dy);
-    AutoTicksAxis(ylim,ytick,yscale()=="log");
+    AutoTicksAxis(ylim,ytick,yscale()=="log",1,dy);
   // UNIMPLEMENTED
   // if(ztickmode()=="auto")
   //   AutoTicksAxis(zlim,ztick,zscale()=="log",2,dz)
