@@ -25,7 +25,7 @@
 #include "globals.h"
 #include "object.h"
 #include "op_com.h"
-// #include "ticks.h"
+#include "ticks.h"
 
 class Axes : public Object {
 public:
@@ -82,8 +82,7 @@ private:
   //! sets up one axis autoscale, called by AutoScale
   bool AutoScaleAxis(int na, double* lim);
   //! sets up one axes ticks, called by AutoTicks
-  // void AutoTicksAxis(Matrix& lim,Matrix& tick,bool log, int direction, double pixelSize);
-  void AutoTicksAxis(Matrix& lim,Matrix& tick,bool log);
+  void AutoTicksAxis(Matrix& lim,Matrix& tick,bool log, int direction, double pixelSize);
   //! Draws one axis (bar & ticks), called by draw
   void DrawOneAxis(axis_name ax,Matrix& ticks,
 		   double* lim, double* lim_o,double ddo,
@@ -99,7 +98,7 @@ private:
   void __setprinting(HandleVect& hv,bool set);
 
   //! Automatic ticks calculators
-  //  Ticks **auto_tickers;
+  Ticks **auto_tickers;
 };
 
 #endif
