@@ -16,15 +16,22 @@
 ## 02111-1307, USA.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{h}} = axes()
+## @deftypefn {Function File} {@var{h}} = axes (@var{args})
 ## Creates a new axes
 ## returning the handle. 
 ##
+## Arguments, if any, are taken as property value pairs
+## and are applied to the axes
+##
 ## @end deftypefn
 ## @seealso{gca,axes_props}
 
 ## Author: Shai Ayal <shaiay@users.sourceforge.net>
 ## Keywords: octplot graphics
-function out = axes()
+function out = axes(varargin)
   out = octplot_command("axes"){1};
+
+  if length(varargin),
+    set(out,varargin{:});
+  endif
 endfunction
