@@ -17,7 +17,7 @@
 
 #include "caselessless.h"
 
-string CaseLessLess::tolower(string in)
+string CaseLessLess::tolower(string in) const
 {
   for(unsigned int i=0;i<in.size();i++)
     if (in[i]>='A' && in[i]<='Z') in[i] += -'A' + 'a';
