@@ -28,9 +28,9 @@ using namespace std;
 
 class CaseLessLess {
 public:
-  bool operator()( const string &x, const string &y ) { return tolower(x) < tolower(y);}
+  bool operator() ( const string &x, const string &y ) const { return tolower(x) < tolower(y);}
 private:
-  string tolower(string in);
+  string tolower(string in) const;
 };
 
 #endif
