@@ -37,12 +37,12 @@ Figure::~Figure()
 Figure::Figure(int x, int y, int w, int h, 
         const char *Caption, 
         FigureWindow* _win, 
-        int _fignum,
+        int fignum,
         ocpl::Handle Parent)
   : Object(Parent) ,
     Fl_Gl_Window(x,y,w,h,Caption) ,
     win(_win),
-    fignum(_fignum),
+    _fignum(fignum),
     in_zoom(false)
 {
 
@@ -111,8 +111,8 @@ void Figure::Parse(ocpl::command& command)
     command.argout(0,ocpl::real,1,1,reinterpret_cast<char*>(hnd),true);
   }
   else if(command.id()==ocpl::clf) {
-    children.Clear(); 
-    AddAxes();
+    children.Clear();
+    currentaxes.Clear();
     dirty = true;
     command.init_argout(0);
   }
@@ -165,8 +165,9 @@ void Figure::draw(void)
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 
   MAKE_REF(children,HandleVect);
-   for ( children.First() ; !children.IsDone() ; children.Next() ) {
-    (::GetObjectD(children.CurrentHandle()))->draw();
+  for ( children.Last() ; !children.IsDoneR() ; children.Prev() ) {
+    //    for ( children.First() ; !children.IsDone() ; children.Next() ) {
+    (::GetObjectD(children.CurrentHandleR()))->draw();
     glTranslatef(0,0,ax_dz);
   }
 
