@@ -52,9 +52,10 @@ public:
   virtual void Parse(ocpl::command& com);
   void DeleteChild(ocpl::Handle Child);
   FigureWindow* win;
+  int fignum() {return _fignum;}
 private:
   enum  print_fmt {ps , eps} ;
-  int fignum;
+  int _fignum;
   void draw();
   void draw_overlay();
   void PostSet(ocpl::command& com);
