@@ -16,12 +16,15 @@
 ## 02111-1307, USA.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{h}} = figure(@var{n})
+## @deftypefn {Function File} {@var{h}} = figure([@var{n},@var{h}])
 ## If called with zero arguments, creates a new figure
 ## returning the handle. 
 ##
-## If called with an argument @var{n}, will make figure @var{n}
-## the current figure if it exists, or return an error
+## If called with an integer argument @var{n}, will make figure
+## number @var{n} current. 
+##
+## If called with a non-integer argument @var{h}, will make the figure
+## with handle @var{h} current.
 ## @end deftypefn
 ## @seealso{gcf}
 
@@ -33,15 +36,28 @@ function out = figure(n)
     out = octplot_command("figure"){1};
     return;
   elseif nargin == 1,
-    figs = get(0,"children");
-    for f=figs'
-      if (get(f,"number")==n),
-        set(0,"currentfigure",f);
-        out = f;
-        return;
+    if floor(n)==n ,
+      figs = get(0,"children");
+      for f=figs'
+	if (get(f,"number")==n),
+          set(0,"currentfigure",f);
+          out = f;
+          return;
+	endif
+      endfor
+      out = octplot_command("figure",n){1};
+      return;
+    elseif ishandle(n),
+      if(strcmp(get(n,"type"),"figure"))
+	set(0,"currentfigure",n);
+	out = n;
+	return
+      else
+	error("handle is not a figure");
       endif
-    endfor
-    error("no such figure");
-  endif
+    else
+      error("no such handle");
+    endif
+  endif    
   usage("figure([n])");
 endfunction
