@@ -54,7 +54,7 @@ void FigureWindow::AddChildren(ocpl::Handle _h)
     Fl_Output(0,h()-status_h,w(),status_h,"");
   Status->textcolor(FL_BLACK);
   Status->color(FL_GRAY);
-  Status->textfont(FL_SCREEN);
+  Status->textfont(FL_COURIER);
   Status->textsize(10);
   Status->box(FL_ENGRAVED_BOX);
 
@@ -137,10 +137,6 @@ int FigureWindow::handle(int event)
     }
     break;
   
-  case FL_FOCUS:
-    return 1;
-    break;
-
   case FL_MOVE:
     if(Fl::event_y()<h()-status_h) {
       fl_cursor(FL_CURSOR_CROSS,FL_BLACK,FL_WHITE);
@@ -240,6 +236,11 @@ int FigureWindow::handle(int event)
     }
     return 1;
     break;
+
+  case FL_FOCUS:
+    Set(0,"CurrentFigure",fig->GetHandle());
+    return 1;
+    break;
   }	
 
   return Fl_Window::handle(event);
