@@ -22,7 +22,7 @@
 ## returns and prints the list of properties for the object
 ## @var{h}.
 ## @end deftypefn
-## @seealso{set,isproperty}
+## @seealso{set,isprop}
 
 ## Author: Shai Ayal <shaiay@users.sourceforge.net>
 ## Keywords: octplot graphics
