@@ -23,17 +23,23 @@
 #include <string>
 #include <iostream>
 
+#include <cfloat>
 #include <cmath>
 #if defined (HAVE_IEEEFP_H)
 #include <ieeefp.h>
 #endif
 
+#if defined (_MSC_VER)
+#define isnan _isnan
+#define finite _finite
+#endif
+
 
 #include <assert.h>
 
 namespace ocpl {
 
-typedef long Handle;
+typedef double Handle;
 typedef double Real;
 
 extern double nan,inf;
@@ -85,7 +91,7 @@ bool Set(ocpl::Handle hnd, char* prop, double* dbl,int len);
 // depth of figure
 const float fig_dpth = 1.0;
 // Number of axes within a figure
-const float num_axes = 8;
+const float num_axes = 16;
 // Number of layers within an axes
 const float num_layr = 1024;
 
@@ -106,7 +112,9 @@ const float markere_z  = 2*dz;
 const float ovlay_z   = fig_dpth;
 
 // macro to move to next layer
+#define TOP_LAYER  glTranslatef(0,0,ax_dz);
 #define NEXT_LAYER glTranslatef(0,0,ly_dz);
+#define PREV_LAYER glTranslatef(0,0,-ly_dz);
 
 //////////////////////////////////////////////////////
 // the following macros make the code more readable
