@@ -38,7 +38,7 @@ Legend::Legend(ocpl::Handle Parent) : Object(Parent)
   COPY_DEFAULT(Location,Radio);
   COPY_DEFAULT(Color,Color);
   COPY_DEFAULT(EdgeColor,ColorNone);
-  COPY_DEFAULT(FaceColor,ColorNone);
+  COPY_DEFAULT(FaceColor,ColorRadio);
   COPY_DEFAULT(FontName,Radio);
   COPY_DEFAULT(FontSize,Scalar);
 }
@@ -48,7 +48,7 @@ void Legend::draw()
   IS_VISIBLE;
 
   MAKE_REF(color,Color);
-  MAKE_REF(facecolor,ColorNone);
+  MAKE_REF(facecolor,ColorRadio);
   MAKE_REF(edgecolor,ColorNone);
   MAKE_REF(fontsize,Scalar);
   MAKE_REF(fontname,Radio);
@@ -101,14 +101,14 @@ void Legend::draw()
 
   // legendbox size
   double width  = 3*px + 20*px + 3*px + lw + 3*px;
-  double height = lh*label.Size() + 6*px; 
+  double height = lh*label.Size() + 6*py; 
 
   Matrix& xlim = ::Get<Matrix>(axes,"xlim");
   Matrix& ylim = ::Get<Matrix>(axes,"ylim");
 
 
   // Legend position according to location - -Ugly
-  double x,y;
+  double x=0,y=0;
   if( location()=="ne" || location()=="northeast") {
     x = xlim(1) - width-10*px;	
     y = ylim(1) - 10*py;
@@ -148,7 +148,7 @@ void Legend::draw()
   xd[2] = x + width - lw - 6*px;
   xd[1] = (xd[0]+xd[2])/2.;
   for(line.First() , dy=0; !line.IsDone() ; line.Next() , dy+=lh ) {
-    yd[0] = yd[1] = yd[2] = y - dy - 0.5*lh - 3*px;
+    yd[0] = yd[1] = yd[2] = y - dy - 0.5*lh - 3*py;
     ::Set(line.CurrentHandle(),"XData",xd,3);
     ::Set(line.CurrentHandle(),"YData",yd,3);
   }
@@ -158,7 +158,7 @@ void Legend::draw()
   pos[0] = x + width - lw - 3*px;
   pos[2] = object_z;
   for(dy=0,label.First(); !label.IsDone() ; label.Next() , dy+=lh ) {
-    pos[1] = y - dy - 0.5*lh - 3*px;
+    pos[1] = y - dy - 0.5*lh - 3*py;
     ::Set(label.CurrentHandle(),"Position",pos,3);
     ::Set(label.CurrentHandle(),"HorizontalAlignment","left");
     ::Set(label.CurrentHandle(),"VerticalAlignment","middle");
@@ -173,8 +173,10 @@ void Legend::draw()
   xp[3] = x;       ; yp[3] = yp[2];
   Matrix XM(xp,1,4);
   Matrix YM(yp,1,4);
-  Patch* ptc = new Patch(Self,XM,YM);
-  ptc->SetProperty("FaceColor",new ColorNone(facecolor));
+  double cv[4]={1.0,1.0,1.0,1.0};
+  facecolor.GetRGBA(cv);
+  Patch* ptc = new Patch(Self,XM,YM,*Real2Matrix(cv[0],cv[1],cv[2],cv[3]));
+  ptc->SetProperty("FaceColor",new ColorRadio(facecolor));
   ptc->SetProperty("EdgeColor",new ColorNone(edgecolor));
   patch.Add(ptc->GetHandle());
   
