@@ -46,50 +46,58 @@
 function handle = legend (varargin)
 
   lgnd = get(gca(),"legend");
+  name_s = 1;
+  name_e = length(varargin);
   
   if length(varargin)==1,
-    arg1 = varargin{1};
+    arg1 = tolower(varargin{1});
     if isstr(arg1),
       if strcmp(arg1,"show") | strcmp(arg1,"on"),
 	set(lgnd,"visible","on");
+	name_s = 2;
       elseif strcmp(arg1,"hide") | strcmp(arg1,"off"),
 	set(lgnd,"visible","off");
+	name_s = 2;
       elseif strcmp(arg1,"toggle") ,
-  if(strcmp(get(lgnd,"visible"),"on"))
-    set(lgnd,"visible","off");
-  else
-      set(lgnd,"visible","on");
-  endif
-      endif
-    endif
-  else
-    ## check for location
-    if length(varargin)>=2,
-      if isstr(varargin{end-1}) & isstr(varargin{end})
-	if strcmp(varargin{end-1},"Location")
-	  set(lgnd,"Location",varargin{end});
+	if(strcmp(get(lgnd,"visible"),"on"))
+	  set(lgnd,"visible","off");
+	  name_s = 2;
+	else
+	  set(lgnd,"visible","on");
+	  name_s = 2;
 	endif
       endif
     endif
-    is=1;
-    for i=1:length(varargin)
-      if ~isstr(varargin{i}),
-	is = 0;
+  endif
+
+  ## check for location
+  if length(varargin)>=2,
+    if isstr(varargin{end-1}) & isstr(varargin{end})
+      if strcmp(tolower(varargin{end-1}),"location")
+	set(lgnd,"Location",varargin{end});
+	name_e -= 2;
       endif
-    endfor
-    if is,
-      chld = get(gca(),"children");
-      li = 1;
-      ci = 1;
-      while(li<=length(varargin) & ci<=length(chld))
-	if strcmp(get(chld(ci),"type"),"Line"),
-	  set(chld(ci++),"label",varargin{li++});
-	endif
-      endwhile
     endif
   endif
-      
+
+  ## check that all remamining ars are strings
+  is=1;
+  for i=name_s:name_e,
+    if ~isstr(varargin{i}),
+      error("all arguments must be strings")
+    endif
+  endfor
+
+  chld = get(gca(),"children");
+  li = name_s;
+  ci = length(chld);
+  while(li<=name_e & ci>0)
+    if strcmp(get(chld(ci),"type"),"line"),
+      set(chld(ci),"label",varargin{li++});
+    endif
+    ci --;
+  endwhile
   
-  if nargout , handle=lgnd ; endif
+    if nargout , handle=lgnd ; endif
 
 endfunction
