@@ -15,6 +15,10 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 //  
 
+#ifdef _MSC_VER
+#define _USE_MATH_DEFINES
+#endif
+
 #include "line_plotter.h"
 #include "gl2ps.h"
 
@@ -35,10 +39,11 @@ GLuint line_plotter::make_marker(Radio& marker, marker_part part)
     mname = "F" + marker();
   else
     mname = "E" + marker();
-  
-  MarkerIter result = Markers.find( mname );
-  if( result != Markers.end())
-    return result->second;
+
+  // FIXME --should cache on figure basis
+  //   MarkerIter result = Markers.find( mname );
+  //   if( result != Markers.end())
+  //     return result->second;
 
   GLuint listIndex;
   // first, ignore all markers w/o fill
@@ -53,126 +58,135 @@ GLuint line_plotter::make_marker(Radio& marker, marker_part part)
     glNewList(listIndex,GL_COMPILE);
   }
 
-  if(mname=="E+") {
-    glBegin(GL_LINES);
-    glVertex2f(-0.5,0);
-    glVertex2f(0.5,0);
-    glVertex2f(0,-0.5);
-    glVertex2f(0,0.5);
-    glEnd();
-  }
-  else if(mname[1]=='o') {
-    if(mname[0]=='E') glBegin(GL_LINE_LOOP);
-    else glBegin(GL_POLYGON);
-    const double pi      = 3.14159265358979;
-    const int segs = 20;
-    for(int i=0;i<segs;i++) glVertex2f(sin(2*pi/segs*i)/2,cos(2*pi/segs*i)/2);
-    glEnd();
-  }
-  else if(mname=="E*") {
-    const double sqrt2d4 = 0.35355339059327;
-    glBegin(GL_LINES);
-    glVertex2f(-0.5,0);
-    glVertex2f(0.5,0);
-    glVertex2f(0,-0.5);
-    glVertex2f(0,0.5);
-    glVertex2f(-sqrt2d4,-sqrt2d4);
-    glVertex2f(+sqrt2d4,+sqrt2d4);
-    glVertex2f(-sqrt2d4,+sqrt2d4);
-    glVertex2f(+sqrt2d4,-sqrt2d4);
-    glEnd();
-  }
-  else if(mname=="E.") {
-    glBegin(GL_POLYGON);
-    glVertex2f(-0.1,-0.1);
-    glVertex2f(-0.1,0.1);
-    glVertex2f(0.1,0.1);
-    glVertex2f(0.1,-0.1);
-    glEnd();
-  }
-  else if(mname[1]=='d') {
-    if(mname[0]=='E') glBegin(GL_LINE_LOOP);
-    else glBegin(GL_POLYGON);
-    glVertex2f(0,0.5);
-    glVertex2f(0.5,0);
-    glVertex2f(0,-0.5);
-    glVertex2f(-0.5,0);
-    glEnd();
-  }
-  else if(mname[1]=='s') {
-    if(mname[0]=='E') glBegin(GL_LINE_LOOP);
-    else glBegin(GL_POLYGON);
-    glVertex2f(-0.5,0.5);
-    glVertex2f(0.5,0.5);
-    glVertex2f(0.5,-0.5);
-    glVertex2f(-0.5,-0.5);
-    glEnd();
-  }
-  else if(mname[1]=='^') {
-    if(mname[0]=='E') glBegin(GL_LINE_LOOP);
-    else glBegin(GL_POLYGON);
-    glVertex2f(0,0.5);
-    glVertex2f(0.5,-0.5);
-    glVertex2f(-0.5,-0.5);
-    glEnd();
-  }
-  else if(mname[1]=='v') {
-    if(mname[0]=='E') glBegin(GL_LINE_LOOP);
-    else glBegin(GL_POLYGON);
-    glVertex2f(0,-0.5);
-    glVertex2f(-0.5,0.5);
-    glVertex2f(0.5,0.5);
-    glEnd();
-  }
-  else if(mname[1]=='>') {
-    if(mname[0]=='E') glBegin(GL_LINE_LOOP);
-    else glBegin(GL_POLYGON);
-    glVertex2f(0.5,0);
-    glVertex2f(-0.5,0.5);
-    glVertex2f(-0.5,-0.5);
-    glEnd();
-  }
-  else if(mname[1]=='<') {
-    if(mname[0]=='E') glBegin(GL_LINE_LOOP);
-    else glBegin(GL_POLYGON);
-    glVertex2f(-0.5,0);
-    glVertex2f(0.5,-0.5);
-    glVertex2f(0.5,0.5);
-    glEnd();
-  }
-  else {//if(mname=="x") {
-    glBegin(GL_LINES);
-    glVertex2f(-0.5,-0.5);
-    glVertex2f(0.5,0.5);
-    glVertex2f(-0.5,0.5);
-    glVertex2f(0.5,-0.5);
-    glEnd();
+  if(listIndex) {
+    if(mname=="E+") {
+      glBegin(GL_LINES);
+      glVertex2f(-0.5,0);
+      glVertex2f(0.5,0);
+      glVertex2f(0,-0.5);
+      glVertex2f(0,0.5);
+      glEnd();
+    }
+    else if(mname[1]=='o') {
+      if(mname[0]=='E') glBegin(GL_LINE_LOOP);
+      else glBegin(GL_POLYGON);
+      const double pi      = 3.14159265358979;
+      const int segs = 20;
+      for(int i=0;i<segs;i++) glVertex2f(sin(2*pi/segs*i)/2,cos(2*pi/segs*i)/2);
+      glEnd();
+    }
+    else if(mname=="E*") {
+      const double sqrt2d4 = 0.35355339059327;
+      glBegin(GL_LINES);
+      glVertex2f(-0.5,0);
+      glVertex2f(0.5,0);
+      glVertex2f(0,-0.5);
+      glVertex2f(0,0.5);
+      glVertex2f(-sqrt2d4,-sqrt2d4);
+      glVertex2f(+sqrt2d4,+sqrt2d4);
+      glVertex2f(-sqrt2d4,+sqrt2d4);
+      glVertex2f(+sqrt2d4,-sqrt2d4);
+      glEnd();
+    }
+    else if(mname=="E.") {
+      glBegin(GL_POLYGON);
+      glVertex2f(-0.1,-0.1);
+      glVertex2f(-0.1,0.1);
+      glVertex2f(0.1,0.1);
+      glVertex2f(0.1,-0.1);
+      glEnd();
+    }
+    else if(mname[1]=='d') {
+      if(mname[0]=='E') glBegin(GL_LINE_LOOP);
+      else glBegin(GL_POLYGON);
+      glVertex2f(0,0.5);
+      glVertex2f(0.5,0);
+      glVertex2f(0,-0.5);
+      glVertex2f(-0.5,0);
+      glEnd();
+    }
+    else if(mname[1]=='s') {
+      if(mname[0]=='E') glBegin(GL_LINE_LOOP);
+      else glBegin(GL_POLYGON);
+      glVertex2f(-0.5,0.5);
+      glVertex2f(0.5,0.5);
+      glVertex2f(0.5,-0.5);
+      glVertex2f(-0.5,-0.5);
+      glEnd();
+    }
+    else if(mname[1]=='^') {
+      if(mname[0]=='E') glBegin(GL_LINE_LOOP);
+      else glBegin(GL_POLYGON);
+      glVertex2f(0,0.5);
+      glVertex2f(0.5,-0.5);
+      glVertex2f(-0.5,-0.5);
+      glEnd();
+    }
+    else if(mname[1]=='v') {
+      if(mname[0]=='E') glBegin(GL_LINE_LOOP);
+      else glBegin(GL_POLYGON);
+      glVertex2f(0,-0.5);
+      glVertex2f(-0.5,0.5);
+      glVertex2f(0.5,0.5);
+      glEnd();
+    }
+    else if(mname[1]=='>') {
+      if(mname[0]=='E') glBegin(GL_LINE_LOOP);
+      else glBegin(GL_POLYGON);
+      glVertex2f(0.5,0);
+      glVertex2f(-0.5,0.5);
+      glVertex2f(-0.5,-0.5);
+      glEnd();
+    }
+    else if(mname[1]=='x') {
+      glBegin(GL_LINES);
+      glVertex2f(-0.5,-0.5);
+      glVertex2f(0.5,0.5);
+      glVertex2f(-0.5,0.5);
+      glVertex2f(0.5,-0.5);
+      glEnd();
+    }
+    else if(mname[1]=='<') {
+      if(mname[0]=='E') glBegin(GL_LINE_LOOP);
+      else glBegin(GL_POLYGON);
+      glVertex2f(-0.5,0);
+      glVertex2f(0.5,-0.5);
+      glVertex2f(0.5,0.5);
+      glEnd();
+    }
+    else { // nothing
+      if(listIndex) {
+	glEndList();
+	glDeleteLists(listIndex,1);
+      }
+      listIndex = 0;
+    }
   }
 
   if(listIndex) glEndList();
-  Markers[mname] = listIndex;
+//   Markers[mname] = listIndex;
     
   return listIndex;
 }
 
+
+// The algorithm for this function was taken from YAPSO by Alexander
+// Barth
 void line_plotter::draw_arrowhead(double x1, double y1,
 			     double x2, double y2,
 			     double l, double w, double a)
 {
-  // first rotate and move so the the endpoint is at the origin
-  // and the end line is parallel to y
-  glPushMatrix();
-  glTranslatef(x2,y2,0);
-  glRotated(180/M_PI*atan2(y2-y1,x2-x1)-90,0,0,1);
-  // and now draw the arrow as two triangles
+  double u=x2-x1;
+  double v=y2-y1;
+
+  a*=l;
+
   glBegin(GL_TRIANGLE_FAN);
-  glVertex2d(0,0);
-  glVertex2d(-w,-l);
-  glVertex2d(0,-l*a);
-  glVertex2d(w,-l);
+  glVertex2d(x2,y2);
+  glVertex2d(x2 - l*u + w*v , y2 - l*v - w*u);
+  glVertex2d(x2 - u*a , y2 - v*a);
+  glVertex2d(x2 - l*u - w*v , y2 - l*v + w*u);
   glEnd();
-  // put everything back in order
-  glPopMatrix();
 }
 
 void line_plotter::plot(Matrix& xdata,
@@ -282,11 +296,16 @@ void line_plotter::plot(Matrix& xdata,
         glCallList(marker_face);
         glTranslatef(0,0,-markerf_z);
       }
-      markeredgecolor.SetColor();
-      glTranslatef(0,0,markere_z);
-      glCallList(marker_edge);
+      if(marker_edge) {
+	markeredgecolor.SetColor();
+	glTranslatef(0,0,markere_z);
+	glCallList(marker_edge);
+      }
       glPopMatrix();
     }
+    // delete list
+    if(marker_edge) glDeleteLists(marker_edge,1);
+    if(marker_face) glDeleteLists(marker_face,1);
   }
 
   // ArrowHeads
@@ -303,7 +322,7 @@ void line_plotter::plot(Matrix& xdata,
 	x1 = LOGIT(2,xscale()=="log");
 	x2 = LOGIT(1,xscale()=="log");
       }
-      draw_arrowhead(x1,y1,x2,y2,arrowlength*dy,arrowwidth*dx,arrowratio);
+      draw_arrowhead(x1,y1,x2,y2,arrowlength,arrowwidth,arrowratio);
     }
 
     if(arrowhead()==">" || arrowhead()=="<>") {
@@ -318,7 +337,7 @@ void line_plotter::plot(Matrix& xdata,
 	x1 = LOGIT(len-1,xscale()=="log");
 	x2 = LOGIT(len,xscale()=="log");
       }
-      draw_arrowhead(x1,y1,x2,y2,arrowlength*dy,arrowwidth*dx,arrowratio);
+      draw_arrowhead(x1,y1,x2,y2,arrowlength,arrowwidth,arrowratio);
     }
 
   }
