@@ -25,8 +25,10 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/types.h>
+#if ! defined (__WIN32__) || defined (__CYGWIN__)
 #include <sys/socket.h>
 #include <sys/wait.h>
+#endif
 #include <sys/stat.h>
 #include <string.h>
 #include <signal.h>
@@ -38,14 +40,47 @@ static bool ShouldWeRedraw=false;
 static int _socket=0;
 
 // default octplot path
+#ifdef _MSC_VER
+static std::string octplot_path;
+static void lookup_octplot_path(void)
+{
+  if (octplot_path.empty()) {
+    int n = 1024;
+    std::string dir(n, '\0');
+    HMODULE hmod = GetModuleHandle("octplot_command.oct");
+
+    while (hmod != NULL) {
+      int status = GetModuleFileName(hmod, &dir[0], n);
+
+      if (status < n) {
+        dir.resize(status);
+        break;
+      }
+      else {
+        n *= 2;
+        dir.resize(n);
+      }
+    }
+
+    if (!dir.empty()) {
+      int pos = dir.rfind("\\");
+      octplot_path = dir.substr(0, pos+1) + "octplot.exe";
+    }
+    else
+      octplot_path = (OPATH "/octplot");
+  }
+}
+#else
 static std::string octplot_path(OPATH "/octplot");
+#endif
 
 int op_connect()
 {
   static pid_t _pid=0; // the pid of octpot==
   int sv[2]; /* the pair of socket descriptors */
   char buffer[100];
-  
+
+#if ! defined (__WIN32__) || defined (__CYGWIN__)
   if(_socket) { // we should check if our child is  still alive
     if(kill(_pid , 0)==0) // but maybe it is a zombie ?
       if(waitpid(_pid,NULL,WNOHANG)==0) 
@@ -72,6 +107,82 @@ int op_connect()
   // Parent
   _socket = sv[0];
   return _socket;
+#else
+  static int wsa_initialized=0;
+  if (!wsa_initialized) {
+	  WSADATA wsa;
+	  WSAStartup(MAKEWORD(2,2), &wsa);
+	  wsa_initialized = 1;
+  }
+
+  if (_socket) {
+    HANDLE hnd = OpenProcess(PROCESS_QUERY_INFORMATION, FALSE, _pid);
+    if (hnd != NULL) {
+      CloseHandle(hnd);
+      return _socket;
+    }
+    
+    warning("OctPlot has died of unknown causes, will spawn a new one");
+    closesocket(_socket);
+    _socket = 0;
+    _pid = 0;
+  }
+
+  int listener = socket(AF_INET, SOCK_STREAM, 0);
+  struct sockaddr_in sock_in;
+  int len;
+
+  sock_in.sin_family = AF_INET;
+  sock_in.sin_port = 0;
+  sock_in.sin_addr.s_addr = INADDR_ANY;
+  if (bind(listener, (struct sockaddr*)&sock_in, sizeof(sock_in)) < 0) {
+	  warning("Cannot create listener socket");
+	  closesocket(listener);
+	  return _socket;
+  }
+  listen(listener, 2);
+  len = sizeof(sock_in);
+  getsockname(listener, (struct sockaddr*)&sock_in, &len);
+  sock_in.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
+  sprintf(buffer, "%d", sock_in.sin_port);
+
+  lookup_octplot_path();
+  std::string cmd = "\"" + octplot_path + "\" " + buffer;
+  STARTUPINFO si;
+  PROCESS_INFORMATION pi;
+  ZeroMemory(&si, sizeof(si));
+  ZeroMemory(&pi, sizeof(pi));
+  if (!CreateProcess(
+			  NULL,
+			  (char*)cmd.c_str(),
+			  NULL,
+			  NULL,
+			  FALSE,
+			  0,
+			  NULL,
+			  NULL,
+			  &si,
+			  &pi)) {
+	  warning("Cannot start octplot process");
+	  closesocket(listener);
+	  return _socket;
+  }
+  _pid = pi.dwProcessId;
+  CloseHandle(pi.hProcess);
+  CloseHandle(pi.hThread);
+
+  len = sizeof(sock_in);
+  int insock = accept(listener, (struct sockaddr*)&sock_in, &len);
+  if (insock == INVALID_SOCKET) {
+	  warning("No client connected");
+	  closesocket(listener);
+	  return _socket;
+  }
+  closesocket(listener);
+  _socket = insock;
+
+  return _socket;
+#endif
 }
 
 DEFUN_DLD (octplot_command, args, nargout,
@@ -83,10 +194,8 @@ send a command to octplot and recive the return argument(s).\n\
 arguments. Currently octplot accepts the following commands:\n\
 \n\
 @table @samp\n\
-@item figure\n\
-Adds a new figure\n\
-@item figure\n\
-Adds a new figure\n\
+@item figure @var{n}\n\
+Adds a new figure with a number @var{n}\n\
 @item axes\n\
 Adds a new axes\n\
 @item line @var{x} @var{y}\n\
@@ -115,6 +224,8 @@ Prints the current figure to fname in postscript\n\
 Do nothing, but load octplot\n\
 @item isprop @var{handle} @var{property}\n\
 checks if the object @var{handle} has the @var{property}\n\
+@item ishnd @var{handle}\n\
+checks if the object @var{handle} exists\n\
 @end table\n\
 @end deftypefn\n")
 {
@@ -153,6 +264,7 @@ checks if the object @var{handle} has the @var{property}\n\
   else if(cmd=="text" ) id = ocpl::text;
   else if(cmd=="delete" ) id = ocpl::del;
   else if(cmd=="isprop" ) id = ocpl::isprop;
+  else if(cmd=="ishnd" ) id = ocpl::ishnd;
   else if(cmd=="noop" ) {
     op_connect();
     retval(0) =0;
@@ -276,6 +388,9 @@ argument is given, uses it as the new octplot executeable\n\
     return retval;
   } 
 
+#ifdef _MSC_VER
+  lookup_octplot_path();
+#endif
   retval(0) = octplot_path;
 
   if( nargin == 1) {
@@ -293,12 +408,14 @@ argument is given, uses it as the new octplot executeable\n\
       return retval;
     }
 
+#if ! defined (__WIN32__) || defined (__CYGWIN__)
     // the new ocplot needs a+x permission -- BUG
     if(st.st_mode & S_IXOTH == 0) {
       error("The new path is not executeable");
       retval(0) = 0;
       return retval;
     }      
+#endif
 
     octplot_path = newpath;
   }
