@@ -26,7 +26,29 @@ int main(int argc, char* argv[])
 
   OctPlotApp *app = OctPlotApp::Get();
 
+#ifndef HAVE_WINSOCK2_H
   int fd = atoi(argv[1]);
+#else
+  WSADATA wsa;
+  WSAStartup(MAKEWORD(2,2), &wsa);
+
+  int port = atoi(argv[1]);
+  int sock = socket(AF_INET, SOCK_STREAM, 0);
+  struct sockaddr_in sock_in;
+
+  sock_in.sin_family = AF_INET;
+  sock_in.sin_port = port;
+  sock_in.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
+
+  if (connect(sock, (struct sockaddr*)&sock_in, sizeof(sock_in)) < 0)
+  {
+	  fprintf(stderr, "Could not connect to server: %08x\n", WSAGetLastError());
+	  closesocket(sock);
+	  exit (1);
+  }
+
+  int fd = sock;
+#endif
   app->Init(fd);
 
 
