@@ -33,7 +33,9 @@ later version.
 #include <stdio.h>
 #include <sys/types.h>
 #include <signal.h>
+#ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
+#endif
 #include "Fl/fl_draw.H"
 
 // 10 msec between polling the socket in cygwin
@@ -63,14 +65,22 @@ Object* OctPlotApp::GetObjectD(const ocpl::Handle hnd)
 /// inf and nan
 void OctPlotApp::Init(int fd)
 {
+
+  // root will get handle = 0
   if(root==0) root=new Root(0);
+  // others will get 2.1, 3.2, ....
+  last_handle = 0.1;
+
+
   _fd = fd;
+#ifndef _MSC_VER
   _ppid = getppid();
+#endif
 
   // fltk's fd_callback is not working on cygwin (FLTK STR #1022), so
   // this hack is a workaround: we do it with a timeout callback using
   // a short timeout. We still pay a time penalty for it !
-#ifndef WIN32
+#if ! defined (WIN32) || defined (_MSC_VER)
   Fl::add_fd(fd,OctPlotApp::fd_callback);
 #endif
 
@@ -101,14 +111,16 @@ void OctPlotApp::timeout_callback(void *_n)
 {
   double next_timeout = TIMEOUT;
 
+#ifndef _MSC_VER
   if(kill(_ppid, 0)==-1)
       exit(0);
+#endif
 
   // fltk's fd_callback is not working on cygwin (FLTK STR #1022), so
   // this hack is a workaround: we do it with a timeout callback using
   // a short timeout. We still pay a time penalty for it !
 
-#ifdef WIN32
+#if defined (WIN32) && ! defined (_MSC_VER)
   struct timeval timeout;
   timeout.tv_sec=0;
   timeout.tv_usec=0;
@@ -145,6 +157,24 @@ void OctPlotApp::fd_callback(int fd,void* y)
   ocpl::command command(fd);
   switch(command.id()) {
     //---------------------------------------------
+    //--------------- ISPHND ----------------------
+    //---------------------------------------------
+  case ocpl::ishnd: 
+    if(command.nargin()!=1) {
+      ocpl::ret_error(command,"Ishnd: accepts 1 arg");
+    }
+    else if(command.argin(0)->id!=ocpl::real) {
+      ocpl::ret_error(command,"Ishnd: arg should be handle");
+    }
+    else {
+      Object* obj=
+	GetObjectD(static_cast<ocpl::Handle>(command.argin(0)->real_data()[0]));
+      double *retval = new double;
+      retval[0] = obj ? 1 : 0;
+      command.argout(0,ocpl::real,1,1,reinterpret_cast<char*>(retval),true);
+    }
+    break;
+     //---------------------------------------------
     //--------------- ISPROP-----------------------
     //---------------------------------------------
   case ocpl::isprop: 
@@ -223,7 +253,11 @@ void OctPlotApp::fd_callback(int fd,void* y)
       // Special case -- deleting root will exit octplot
       command.init_argout(0);
       command.ret(fd);
+#ifndef _MSC_VER
       sleep(1); // just to make sure fd is flushed  
+#else
+      Sleep(1000);
+#endif
       exit(0);
     }
     else {
