@@ -25,7 +25,7 @@
 //! Holds Patch objects
 class Patch : public Object {
 public:
-  Patch(ocpl::Handle Parent,Matrix& XData, Matrix& YData); 
+  Patch(ocpl::Handle Parent,Matrix& XData, Matrix& YData, Matrix& CData); 
   ~Patch() {_DEBUG_PRINT("In ~patch\n");};
   void draw();
 };
