@@ -33,7 +33,9 @@ void  HandleVectNoOwn::Add(const ocpl::Handle new_handle)
   for ( First() ; !IsDone() ; Next() )
     if( CurrentHandle() == new_handle) return;
   
-  Value.push_back(new_handle);
+  Value.push_front(new_handle);
+
+  //  Value.push_back(new_handle);
 }
 
 void  HandleVectNoOwn::Delete(const ocpl::Handle handle) 
@@ -131,13 +133,15 @@ void HandleVectNoOwn::Set(ocpl::command& com)
   
   typedef std::set<ocpl::Handle> hset ;
   hset os,ns;
+  HandleVectList::iterator im;
+  int i;
 
-  for(int i=0;i<com.argin(2)->nc*com.argin(2)->nr;i++) {
+  for(i=0, im=Value.begin() ;i<com.argin(2)->nc*com.argin(2)->nr;i++,im++) {
     ocpl::Handle hnd = static_cast<ocpl::Handle>(
       (reinterpret_cast<double*>(com.argin(2)->data))[i]);
     if(GetObjectD(hnd)) {
       ns.insert(hnd);
-      os.insert(Value[i]);
+      os.insert(*im);
     }
     else {
       ret_error(com,"Handle Vector: no such handle");
@@ -151,6 +155,7 @@ void HandleVectNoOwn::Set(ocpl::command& com)
       ret_error(com,"New value must be a permutation of current value");
       return;
     }
+
   }
 
   // OK -- it's legal, now let's copy everything into place in the right order
