@@ -18,12 +18,12 @@
 #ifndef PROP_HANDLE_H
 #define PROP_HANDLE_H
 
-#include <vector>
+#include <list>
 #include "property.h"
 #include "object.h"
 
 
-typedef std::vector<ocpl::Handle> HandleVectList ;
+typedef std::list<ocpl::Handle> HandleVectList ;
 
 //! A vector of handles (actually implemented as a set)
 class HandleVectNoOwn : public Property {
@@ -44,7 +44,11 @@ public:
   void First() {im = Value.begin();} //!< Iterator function
   void Next() {im++;} //!< Iterator function
   bool IsDone() {return im==Value.end();} //!< Iterator function
+  void Last() {ir = Value.rbegin();} //!< Iterator function
+  void Prev() {ir++;} //!< Iterator function
+  bool IsDoneR() {return ir==Value.rend();} //!< Iterator function
   ocpl::Handle CurrentHandle() {return *im;} //!< Iterator function
+  ocpl::Handle CurrentHandleR() {return *ir;} //!< reverse Iterator function
   bool exist(ocpl::Handle il) {
     for (First() ; !IsDone() ; Next() )
       if(il == CurrentHandle()) return true;
@@ -55,6 +59,7 @@ public:
   void Set(ocpl::command&);
 protected:
   HandleVectList::iterator im;
+  HandleVectList::reverse_iterator ir;
   HandleVectList Value;
 };
 
