@@ -17,6 +17,9 @@
 
 #include <iostream>
 #include <stdio.h>
+#include <vector>
+#include <algorithm>
+#include <FL/Fl.H>
 #include "figure.h"
 #include "figurewindow.h"
 #include "property.h"
@@ -67,7 +70,7 @@ Root::Root(ocpl::Handle Parent) : Object(Parent)
   Properties["DefaultAxesZScale"] = new Radio(as);
   Properties["DefaultAxesXAxisLocation"] = new Radio("|top|{bottom}|");
   Properties["DefaultAxesYAxisLocation"] = new Radio("|right|{left}|");
-  Properties["DefaultAxesBox"] = new Radio(offon);
+  Properties["DefaultAxesBox"] = new Radio(onoff);
   const double color_order[] ={
     1,0,0,1,0,1,0,
     0,0,1,1,1,0,0,
@@ -80,6 +83,12 @@ Root::Root(ocpl::Handle Parent) : Object(Parent)
     co[i] = color_order[i];
   }
   Properties["DefaultAxesColorOrder"] = new Matrix(co,7,4);
+  Properties["DefaultAxesFontSize"] = new Scalar(10);
+  Properties["DefaultAxesTag"] = new String("");
+
+  // line & marker for types with lines
+  const char* linestyle = "|{-}|--|:|-.|none|";
+  const char* marker = "|{none}|+|o|*|.|x|s|d|^|v|>||<||p||h|";
 
   // Text
   Properties["DefaultTextColor"] =  new Color('k');
@@ -92,10 +101,10 @@ Root::Root(ocpl::Handle Parent) : Object(Parent)
     new Radio("|{sans}|mono|serif|");
   Properties["DefaultTextFontSize"] = new Scalar(10);
   Properties["DefaultTextRotation"] = new Scalar(0);
-
-  // line & marker for types with lines
-  const char* linestyle = "|{-}|--|:|-.|none|";
-  const char* marker = "|{none}|+|o|*|.|x|s|d|^|v|>||<||p||h|";
+  Properties["DefaultTextBackgroundColor"] = new ColorNone("none");
+  Properties["DefaultTextEdgeColor"] = new ColorNone("none");
+  Properties["DefaultTextLineWidth"] =  new Scalar(1.0);
+  Properties["DefaultTextLineStyle"] = new Radio(linestyle);
 
   // Line
   Properties["DefaultLineColor"] =  new Color('r');
@@ -107,12 +116,14 @@ Root::Root(ocpl::Handle Parent) : Object(Parent)
   Properties["DefaultLineLineStyle"] = new Radio(linestyle);
   Properties["DefaultLineMarker"]    = new Radio(marker);
   Properties["DefaultLineArrowHead"] = new Radio("|{none}|<|>|<>|");
-  Properties["DefaultLineArrowLength"] = new Scalar(5.0);
-  Properties["DefaultLineArrowWidth"] = new Scalar(3.0);
-  Properties["DefaultLineArrowRatio"] = new Scalar(0.7);
+  Properties["DefaultLineArrowLength"] = new Scalar(0.1);
+  Properties["DefaultLineArrowWidth"] = new Scalar(0.05);
+  Properties["DefaultLineArrowRatio"] = new Scalar(0.5);
 
   // Patch
-  Properties["DefaultPatchFaceColor"] = new ColorNone('r');
+  Properties["DefaultPatchFaceAlpha"] = new Scalar(1.0);
+  Properties["DefaultPatchFaceColor"] = new 
+    ColorRadio('k',false,"|{flat}|interp|none|");
   Properties["DefaultPatchEdgeColor"] = new ColorNone('k');
   Properties["DefaultPatchLineStyle"] = new Radio(linestyle);
   Properties["DefaultPatchLineWidth"] =  new Scalar(1.0);
@@ -124,10 +135,21 @@ Root::Root(ocpl::Handle Parent) : Object(Parent)
 
   // Surface
   Properties["DefaultSurfaceClipping"] = new Radio(onoff);
+  Properties["DefaultSurfaceLineWidth"] = new Scalar(0.5); 
+  Properties["DefaultSurfaceFaceColor"] = new ColorRadio('g',true,"|{flat}|interp|none|");
+  Properties["DefaultSurfaceEdgeColor"] = new ColorRadio('k',false,"|{none}|");
+  Properties["DefaultSurfaceLineStyle"] = new Radio(linestyle);
+  Properties["DefaultSurfaceMarker"] = new Radio(marker);
+  Properties["DefaultSurfaceMarkerFaceColor"] = new Color('w');
+  Properties["DefaultSurfaceMarkerEdgeColor"] = new Color('r');
+  Properties["DefaultSurfaceMarkerSize"] = new Scalar(10);
+  Properties["DefaultSurfaceMeshStyle"] = new Radio("|{both}|column|row|");
+  Properties["DefaultSurfaceFaceAlpha"] = new Scalar(1.0);
 
   // Legend
   Properties["DefaultLegendColor"]     = new Color('k');
-  Properties["DefaultLegendFaceColor"] = new ColorNone('w');
+  Properties["DefaultLegendFaceColor"] = new
+    ColorRadio('w',false,"|{flat}|interp|none|");
   Properties["DefaultLegendEdgeColor"] = new ColorNone('k');
   Properties["DefaultLegendClipping"]  = new Radio(offon);
   Properties["DefaultLegendFontName"]  = 
@@ -137,11 +159,35 @@ Root::Root(ocpl::Handle Parent) : Object(Parent)
     new Radio("|n|{ne}|e|se|s|sw|w|nw|north|northeast|east|southeast|south|southwest|west|northwest|");
 
   // FontDir
-  Properties["DefaultFontDir"]  = new String(OPATH "/fonts/");
+#ifndef _MSC_VER
+  Properties["DefaultFontDir"]  = new String(FONTPATH);
+#else
+  int n = 1024;
+  std::string fpath(n, '\0');
+
+  while (true) {
+    int status = GetModuleFileName(0, &fpath[0], n);
+
+    if (status < n) {
+      fpath.resize(status);
+      break;
+    }
+    else {
+      n *= 2;
+      fpath.resize(n);
+    }
+  }
+
+  if (!fpath.empty()) {
+    int pos = fpath.rfind("\\oct\\");
+    Properties["DefaultFontDir"]  = new String(fpath.substr(0, pos) + "\\fonts");
+  }
+#endif
 }
 
 //! Addes a new Figure object, taking care of the numbering etc...
-void Root::AddFigure()
+// requested num is now silently ignored ....
+void Root::AddFigure(int requested_num)
 {
   char Caption[25];
   MAKE_REF(children,HandleVect);
@@ -149,14 +195,9 @@ void Root::AddFigure()
   MAKE_REF(defaultfigureposition,Matrix);
 
   // get a new figure number. This should be the lowest available
-  static int max_num=1;
-  int fignum;
-  if(free_nums.empty()) fignum=max_num++;
-  else {
-    fignum= *(free_nums.begin());
-    free_nums.erase(free_nums.begin());
-  }
-
+  int fignum = GetFignum(requested_num);
+  if(fignum<0) return; // this figure exists
+  
   sprintf(Caption,"octplot - Figure %d",fignum);
 
   FigureWindow *nf = 
@@ -172,7 +213,7 @@ void Root::AddFigure()
   nf->AddChildren(GetHandle());
   Figure* Current = nf->fig;
   children.Add(Current->GetHandle());
-  Current->AddAxes();
+//  Current->AddAxes();
   currentfigure.Clear();
   currentfigure.Add(Current->GetHandle());
 
@@ -182,8 +223,6 @@ void Root::AddFigure()
 void Root::DelWindow(FigureWindow* fw)
 {
   ocpl::Handle hnd = fw->fig->GetHandle();
-  free_nums.insert(fw->fignum);
-  delete fw;
   DeleteChild(hnd);
 }
 
@@ -191,7 +230,11 @@ void Root::DeleteChild(ocpl::Handle Child)
 {
   MAKE_REF(children,HandleVect);
   MAKE_REF(currentfigure,HandleScalar);
-  
+
+  Figure *fig = dynamic_cast<Figure*>(GetObjectD(Child)); 
+  fig->win->hide();
+  delete fig->win;
+
   children.Delete(Child);
   if(currentfigure()==Child)
   {
@@ -202,7 +245,11 @@ void Root::DeleteChild(ocpl::Handle Child)
         last = children.CurrentHandle();
         children.Next();
     }
-    if(last) currentfigure.Add(last);
+    if(last) {
+      currentfigure.Add(last);
+      Figure *fig = dynamic_cast<Figure*>(GetObjectD(last));
+      Fl::focus(fig->win);
+    }
   }
 }
 
@@ -212,11 +259,18 @@ void Root::Parse(ocpl::command& command)
 
   if(command.id()==ocpl::figure) {
     command.parsed(true);
-    if(command.nargin()!=0) {
-      ret_error(command,"figure accepts 0 arguments");
+    if(command.nargin()>1) {
+      ret_error(command,"figure accepts 0 or 1 arguments");
       return;
     }
-    AddFigure();
+    
+    if(command.nargin()==1) {
+      int newfig = static_cast<int>(command.argin(0)->real_data()[0]);
+      AddFigure(newfig);
+    }
+    else{
+      AddFigure();
+    }
   
     command.dirty(true);
     
@@ -248,7 +302,7 @@ bool Root::PreSet(ocpl::command& com)
   
   std::string prop(tolower(com.argin(1)->data));
   
-  if(prop=="currenfigure") {
+  if(prop=="currentfigure") {
     ocpl::Handle new_ca = 
       static_cast<ocpl::Handle>(*(com.argin(2)->real_data()));
     if(!children.exist(new_ca)) {
@@ -259,3 +313,62 @@ bool Root::PreSet(ocpl::command& com)
 
   return true;
 }
+
+void Root::PostSet(ocpl::command& com)
+{
+  MAKE_REF(children,HandleVect)
+  MAKE_REF(currentfigure,HandleScalar)
+  
+  std::string prop(tolower(com.argin(1)->data));
+  
+  // raise current figure
+  if(prop=="currentfigure") {
+    Figure* fig = dynamic_cast<Figure*>(GetObjectD(currentfigure()));
+    assert(fig);
+    fig->win->show();
+  }
+}
+
+int Root::GetFignum(int newnum) 
+{
+  int retnum;
+  std::vector<int> nums;
+
+  // populate nums vector
+  MAKE_REF(children,HandleVect);
+  for(children.First(); !children.IsDone() ; children.Next() )
+    nums.push_back(dynamic_cast<Figure*>
+		   ( (::GetObjectD(children.CurrentHandle())))->fignum());
+
+  if(newnum == -1) {
+    //find lowest free number
+
+    // special casses
+    if(nums.size()==0) {
+      retnum=1;
+    }
+    else if(nums.size()==1) {
+      if(nums[0] == 1) retnum = 2;
+      else retnum = 1;
+    }
+    else { // general case
+      std::sort(nums.begin(),nums.end());
+      if(nums[0] > 1) retnum = 1;
+      else {
+	int i;
+	for(i=1;i<nums.size();i++)
+	  if(nums[i] - nums[i-1] > 1) break;
+
+	retnum = nums[i-1]+1;
+      }
+    }
+  }
+  else { // number was requested -- see if it exists
+    retnum = newnum;
+    for(int i=0;i<nums.size();i++) {
+      if(nums[i]==newnum) retnum = -1;
+    }
+  }
+      
+  return retnum;
+}
