@@ -21,7 +21,7 @@
 ## graphics object referenced by @var{h} to the value @var{v}.
 ## Multiple pairs of @var{p},@var{v} are allowed
 ## @end deftypefn
-## @seealso{get,isproperty}
+## @seealso{get,isprop}
 
 ## Author: shaia
 
