@@ -39,6 +39,10 @@ Text::Text(ocpl::Handle Parent,
   COPY_DEFAULT(Rotation,Scalar);
   COPY_DEFAULT(HorizontalAlignment,Radio);
   COPY_DEFAULT(VerticalAlignment,Radio);
+  COPY_DEFAULT(BackgroundColor,ColorNone);
+  COPY_DEFAULT(EdgeColor,ColorNone);
+  COPY_DEFAULT(LineWidth,Scalar);
+  COPY_DEFAULT(LineStyle,Radio);
 
   Font = 0L;
   _w = 0;
@@ -129,6 +133,10 @@ void Text::draw()
   MAKE_REF(horizontalalignment,Radio);
   MAKE_REF(verticalalignment,Radio);
   MAKE_REF(rotation,Scalar);
+  MAKE_REF(backgroundcolor,ColorNone);
+  MAKE_REF(edgecolor,ColorNone);
+  MAKE_REF(linewidth,Scalar);
+  MAKE_REF(linestyle,Radio);
   std::string psfontname;
   
   if(string()=="") return;
