@@ -16,15 +16,19 @@
 ## 02111-1307, USA.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} title(@var{label})
+## @deftypefn {Function File} {@var{h}}=title(@var{label})
 ## sets the title of the current axis to @var{label}  
+## Returns a handle to the text used as title
 ## @end deftypefn
 ## @seealso{set}
 
 ## Author: Shai Ayal <shaiay@users.sourceforge.net>
 ## Keywords: octplot graphics
-function title(label)
+function h=title(label)
   tith = get(gca(),"title");
   set(tith,"string",label);
   set(tith,"FontSize",13);
+  if nargout ,
+    h = tith;
+  endif
 endfunction
