@@ -16,13 +16,23 @@
 ## 02111-1307, USA.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} xlabel(@var{label})
-## sets the xlabel of the current axis to @var{label}  
+## @deftypefn {Function File} {@var{h}} = xlabel(@var{label},@var{args})
+## sets the xlabel of the current axis to @var{label} and returns
+## the handle to the text object used as label.
+## Other arguments are taken as property pairs.
 ## @end deftypefn
 ## @seealso{set}
 
 ## Author: Shai Ayal <shaiay@users.sourceforge.net>
 ## Keywords: octplot graphics
-function xlabel(label)
-  set(get(gca,"xlabel"),"string",label);
+function h=xlabel(label,varargin)
+  hnd = get(gca(),"xlabel");
+  set(hnd,"string",label);
+  if length(varargin),
+    set(hnd,varargin{:});
+  endif
+
+  if nargout,
+    h=hnd;
+  endif
 endfunction
