@@ -16,15 +16,26 @@
 ## 02111-1307, USA.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} ylabel(@var{label})
-## sets the ylabel of the current axis to @var{label}  
+## @deftypefn {Function File} {@var{h}} = xlabel(@var{label},@var{args})
+## sets the xlabel of the current axis to @var{label} and returns
+## the handle to the text object used as label.
+## Other arguments are taken as property pairs.
 ## @end deftypefn
 ## @seealso{set}
 
 ## Author: Shai Ayal <shaiay@users.sourceforge.net>
 ## Keywords: octplot graphics
-function ylabel(label)
-  h = get(gca,"ylabel");
-  set(h,"string",label);
-  set(h,"rotation",90);
+
+function h=ylabel(label,varargin)
+
+  hnd = get(gca(),"ylabel");
+  set(hnd,"string",label);
+  set(hnd,"rotation",90);
+  if length(varargin),
+    set(hnd,varargin{:});
+  endif
+
+  if nargout,
+    h=hnd;
+  endif
 endfunction
